==> jc-1.4.0.tar.gz: java/text/Annotation.h <==
// public class java.text.Annotation

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 687d454d2df09fc5 java_text_Annotation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_Annotation_H_
#define _JC_java_text_Annotation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_Annotation$sub_refs	_jc_java_text_Annotation$sub_refs;
typedef struct _jc_java_text_Annotation$sub_nonrefs	_jc_java_text_Annotation$sub_nonrefs;
typedef struct _jc_java_text_Annotation$refs	_jc_java_text_Annotation$refs;
typedef struct _jc_java_text_Annotation$nonrefs	_jc_java_text_Annotation$nonrefs;
typedef struct _jc_java_text_Annotation$object	_jc_java_text_Annotation$object;

typedef const struct _jc_java_text_Annotation$vmethods	_jc_java_text_Annotation$vmethods;
typedef const struct _jc_java_text_Annotation$vtable	_jc_java_text_Annotation$vtable;
typedef const struct _jc_java_text_Annotation$vtype	_jc_java_text_Annotation$vtype;

// Constructors
extern void _jc_java_text_Annotation$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_text_Annotation$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_text_Annotation$object *);
extern struct _jc_java_lang_String$object *_jc_java_text_Annotation$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_Annotation$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_Annotation$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_text_Annotation$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_text_Annotation$vmethods {
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_text_Annotation$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_Annotation$object *);
};

// Vtable
struct _jc_java_text_Annotation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_Annotation$vmethods	java_text_Annotation;
};

// Vtype
struct _jc_java_text_Annotation$vtype {
	_jc_type			type;
	_jc_java_text_Annotation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_Annotation$sub_refs {
	struct _jc_java_lang_Object$object	*attrib;
};

// Reference instance fields (object)
struct _jc_java_text_Annotation$refs {
    _jc_java_text_Annotation$sub_refs	java_text_Annotation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_Annotation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_Annotation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_Annotation$sub_nonrefs	java_text_Annotation;
};

// Object instance structure
struct _jc_java_text_Annotation$object {
	_jc_java_text_Annotation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_Annotation$vtype	*vtype;
	_jc_java_text_Annotation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_Annotation$vtype _jc_java_text_Annotation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_Annotation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_Annotation$class_object;

#endif	/* _JC_java_text_Annotation_H_ */

==> jc-1.4.6.tar.gz: java/text/Annotation.h <==
// public class java.text.Annotation

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 687d454d2df09fc5 java_text_Annotation

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_Annotation_H_
#define _JC_java_text_Annotation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_Annotation$sub_refs	_jc_java_text_Annotation$sub_refs;
typedef struct _jc_java_text_Annotation$sub_nonrefs	_jc_java_text_Annotation$sub_nonrefs;
typedef struct _jc_java_text_Annotation$refs	_jc_java_text_Annotation$refs;
typedef struct _jc_java_text_Annotation$nonrefs	_jc_java_text_Annotation$nonrefs;
typedef struct _jc_java_text_Annotation$object	_jc_java_text_Annotation$object;

typedef const struct _jc_java_text_Annotation$vmethods	_jc_java_text_Annotation$vmethods;
typedef const struct _jc_java_text_Annotation$vtable	_jc_java_text_Annotation$vtable;
typedef const struct _jc_java_text_Annotation$vtype	_jc_java_text_Annotation$vtype;

// Constructors
extern void _jc_java_text_Annotation$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_text_Annotation$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_text_Annotation$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_text_Annotation$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_Annotation$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_Annotation$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_text_Annotation$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_text_Annotation$vmethods {
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_text_Annotation$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_Annotation$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_Annotation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_Annotation$vmethods	java_text_Annotation;
};

// Vtype
struct _jc_java_text_Annotation$vtype {
	_jc_type			type;
	_jc_java_text_Annotation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_Annotation$sub_refs {
	struct _jc_java_lang_Object$object	*attrib;
};

// Reference instance fields (object)
struct _jc_java_text_Annotation$refs {
    _jc_java_text_Annotation$sub_refs	java_text_Annotation;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_Annotation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_Annotation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_Annotation$sub_nonrefs	java_text_Annotation;
};

// Object instance structure
struct _jc_java_text_Annotation$object {
	_jc_java_text_Annotation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_Annotation$vtype	*vtype;
	_jc_java_text_Annotation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_Annotation$vtype _jc_java_text_Annotation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_Annotation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_Annotation$class_object;

#endif	/* _JC_java_text_Annotation_H_ */
